mui.init();

var vm = new Vue( {
  el: '.mui-content',
  data: {
    companyInfo: {},
    channelList: [], //销售渠道列表
    styleList: [], //类目品类列表
    fabricCategoryList: [], //擅长面料类别列表
    oCategoryList: [], //擅长加工类目品类列表
    role: localStorage.getItem( 'role' )
  },
  computed: {
    companyProvince: function () {
      if( this.companyInfo.province ) {
        return this.companyInfo.province + ' ' + this.companyInfo.city + ' ' + this.companyInfo.county;
      } else {
        return '';
      }
    },
    //面料大类
    fabricCategory: function () {
      var str = '',
        fabricArray = this.companyInfo.fabric_category,
        tempArr = [],
        tempFabricId = [];
      if( fabricArray === undefined || fabricArray.length == 0 ) {
        str = '请选择(多选)'
      } else {
        for( var i in fabricArray ) {
          tempArr.push( fabricArray[ i ].category_name );
          tempFabricId.push( fabricArray[ i ].category_id );
        }
        this.companyInfo.fabric_category_id = tempFabricId;
        str = tempArr.join( '、' );
      }
      return str;
    },
    //类目品类
    oCategory: function () {
      var str = '',
        categoryArray = this.companyInfo.o_category;
      tempArr = [],
        tempCategoryId = [];
      if( categoryArray === undefined || categoryArray.length == 0 ) {
        str = '请选择(多选)'
      } else {
        for( var i in categoryArray ) {
          tempArr.push( categoryArray[ i ].cate_name );
          tempCategoryId.push( categoryArray[ i ].cate_id );
        }
        this.companyInfo.o_category_id = tempCategoryId;
        str = tempArr.join( '、' );
      }
      return str;
    },
    //主要销售渠道
    channel: function () {
      var str = '',
        channelArray = this.companyInfo.channel,
        tempArr = [],
        tempChannelId = [];
      if( channelArray === undefined || channelArray.length == 0 ) {
        str = '请选择(多选)'
      } else {
        for( var i in channelArray ) {
          tempArr.push( channelArray[ i ].channel_name );
          tempChannelId.push( channelArray[ i ].channel_id );
        }
        this.companyInfo.channel_id = tempChannelId;
        str = tempArr.join( '、' );
      }
      return str;
    },
    //主营类目品类
    style: function () {
      var str = '',
        stylelArray = this.companyInfo.style,
        tempArr = [],
        tempStyleId = [];
      if( stylelArray === undefined || stylelArray.length == 0 ) {
        str = '请选择(多选)'
      } else {
        for( var i in stylelArray ) {
          tempArr.push( stylelArray[ i ].style_name );
          tempStyleId.push( stylelArray[ i ].style_id );
        }
        this.companyInfo.style_id = tempStyleId;
        str = tempArr.join( '、' );
      }
      return str;
    }
  },
  mounted: function () {
    mui.plusReady( function () {
      var self = plus.webview.currentWebview();
      vm.companyInfo = self.my_other_message;
      if( vm.role == '1' ) {
        _getChannelList(); //获取销售渠道
        _getStyleList(); //获取类目品类
      } else {
        _getFabricCategory(); //获取面料大类
        _getCategory(); //获取加工类目品类列表
      }
    } )
  },

} )

$( ".sure-btn" ).click( function () {
  if( vm.role == '1' ) {
    delete vm.companyInfo.machine;
    delete vm.companyInfo.fabric_category_id;
    delete vm.companyInfo.o_category_id;
  } else {
    delete vm.companyInfo.style_id;
    delete vm.companyInfo.channel_id;
  }

  if( !vm.companyInfo.county_id ) {
    mui.toast( '请选择公司地址' )
  } else if( !vm.companyInfo.address ) {
    mui.toast( "请输入公司详细地址" );
  } else {
    $ajax( "/UserCenter/otherSave", vm.companyInfo, function ( res ) {
      mui.alert( res.msg, function () {
        var company = plus.webview.getWebviewById( 'my_setting.html' );
        //触发列表界面的自定义事件（refresh）,从而进行数据刷新
        mui.fire( company, 'refresh' );
        vm.companyInfo = {};
        mui.back();
      } )
    } )
  }
} )

//进行选择框的时候，输入框失焦
mui(".mui-table-view-cell").each(function(){
  mui(this).on('tap','a',function(){
    var input = document.getElementsByTagName("input");
    for(var i = 0; i < input.length; i++) {
      input[i].blur();
    }
  })
})

/**
 * 选择省市区
 */
$( ".area-cell" ).on( "tap", function () {
  var $that = $( this );
  var _getParam = function ( obj, param ) {
    return obj[ param ] || '';
  };
  var cityPicker3 = new mui.PopPicker( {
    layer: 3
  } );
  cityPicker3.setData( cityData3 );
  cityPicker3.show( function ( items ) {
    vm.companyProvince = _getParam( items[ 0 ], 'text' ) + " " + _getParam( items[ 1 ], 'text' ) + " " + _getParam( items[ 2 ], 'text' );
    vm.companyInfo.province = _getParam( items[ 0 ], 'text' );
    vm.companyInfo.city = _getParam( items[ 1 ], 'text' );
    vm.companyInfo.county = _getParam( items[ 2 ], 'text' );
    vm.companyInfo.province_id = _getParam( items[ 0 ], 'value' );
    vm.companyInfo.city_id = _getParam( items[ 1 ], 'value' );
    vm.companyInfo.county_id = _getParam( items[ 2 ], 'value' );
  } );
} );

/**
 * 获取加工面料大类列表
 */
function _getFabricCategory() {
  $ajax( "/UserCenter/getFabricCategory", {}, function ( res ) {
    var fabricArray = vm.companyInfo.fabric_category;
    if( res.status == 200 ) {
      var content = res.content;
      if( fabricArray == undefined || fabricArray.length == 0 ) {
        for( var i in content ) {
          content[ i ][ 'selected' ] = false;
        }
      } else {
        for( var i in content ) {
          for( var j in fabricArray ) {
            if( content[ i ][ 'category_id' ] == fabricArray[ j ][ 'category_id' ] ) {
              content[ i ][ 'selected' ] = true;
              break;
            } else {
              content[ i ][ 'selected' ] = false;
            }
          }
        }
      }
      vm.fabricCategoryList = content;
    } else {
      mui.alert( res.msg );
    }
  } )
}

/**
 * 获取加工类目品类列表
 */
function _getCategory() {
  $ajax( "/UserCenter/getCategory", {}, function ( res ) {
    var categoryArray = vm.companyInfo.o_category;
    if( res.status == 200 ) {
      var content = res.content;
      if( categoryArray == undefined || categoryArray.length == 0 ) {
        for( var i in content ) {
          content[ i ][ 'selected' ] = false;
        }
      } else {
        for( var i in content ) {
          for( var j in categoryArray ) {
            if( content[ i ][ 'cate_id' ] == categoryArray[ j ][ 'cate_id' ] ) {
              content[ i ][ 'selected' ] = true;
              break;
            } else {
              content[ i ][ 'selected' ] = false;
            }
          }
        }
      }
      vm.oCategoryList = content;
    } else {
      mui.alert( res.msg );
    }
  } )
}

/**
 * 获取销售渠道列表
 */
function _getChannelList() {
  $ajax( "/UserCenter/getChannel", {}, function ( res ) {
    var channelArray = vm.companyInfo.channel;
    if( res.status == 200 ) {
      var content = res.content;
      if( channelArray == undefined || channelArray.length == 0 ) {
        for( var i in content ) {
          content[ i ][ 'selected' ] = false;
        }
      } else {
        for( var i in content ) {
          for( var j in channelArray ) {
            if( content[ i ][ 'channel_id' ] == channelArray[ j ][ 'channel_id' ] ) {
              content[ i ][ 'selected' ] = true;
              break;
            } else {
              content[ i ][ 'selected' ] = false;
            }
          }
        }
      }
      vm.channelList = content;
    } else {
      mui.alert( res.msg );
    }
  } )
}

/**
 * 获取主营品类列表
 */
function _getStyleList() {
  $ajax( "/UserCenter/getStyle", {}, function ( res ) {
    var styleArray = vm.companyInfo.style;
    if( res.status == 200 ) {
      var content = res.content;
      if( styleArray == undefined || styleArray.length == 0 ) {
        for( var i in content ) {
          content[ i ][ 'selected' ] = false;
        }
      } else {
        for( var i in content ) {
          for( var j in styleArray ) {
            if( content[ i ][ 'style_id' ] == styleArray[ j ][ 'style_id' ] ) {
              content[ i ][ 'selected' ] = true;
              break;
            } else {
              content[ i ][ 'selected' ] = false;
            }
          }
        }
      }
      vm.styleList = content;
    } else {
      mui.alert( res.msg );
    }
  } )
}

/**
 * 选择加工面料
 */
function selectFabric( index ) {
  vm.fabricCategoryList[ index ][ 'selected' ] = !vm.fabricCategoryList[ index ][ 'selected' ];
}

/**
 * 选择加工类目品类
 */
function selectCategory( index ) {
  vm.oCategoryList[ index ][ 'selected' ] = !vm.oCategoryList[ index ][ 'selected' ];
}

/**
 * 选择销售渠道
 */
function selectChannel( index ) {
  vm.channelList[ index ][ 'selected' ] = !vm.channelList[ index ][ 'selected' ];
}

/**
 * 选择主营类目
 */
function selectStyle( index ) {
  vm.styleList[ index ][ 'selected' ] = !vm.styleList[ index ][ 'selected' ];
};

//关闭弹窗事件
$( ".mui-popover .mui-icon-closeempty" ).on( "tap", function () {
  mui( '.mui-popover' ).popover( 'hide' );
} )

//面料大类弹窗内确定事件
$( "#fabric_category button" ).on( "tap", function () {
  mui( '.mui-popover' ).popover( 'hide' );
  var _selectedItemId = [],
    _selectedObject = {},
    tempArr = [];
  if( $( "#fabric_category .active-item" ).length > 0 ) {
    $( "#fabric_category .active-item" ).each( function ( index, ele ) {
      _selectedItemId.push( $( ele ).attr( 'id' ) );
      _selectedObject[ 'category_id' ] = $( ele ).attr( 'id' );
      _selectedObject[ 'category_name' ] = $( ele ).text();
      tempArr.push( _selectedObject );
      _selectedObject = {};
    } )
  }
  vm.companyInfo.fabric_category = tempArr;
  vm.companyInfo.fabric_category_id = _selectedItemId;
} );

//加工类目品类弹窗内确定事件
$( "#o_category button" ).on( "tap", function () {
  mui( '.mui-popover' ).popover( 'hide' );
  var _selectedItemId = [],
    _selectedObject = {},
    tempArr = [];
  if( $( "#o_category .active-item" ).length > 0 ) {
    $( "#o_category .active-item" ).each( function ( index, ele ) {
      _selectedItemId.push( $( ele ).attr( 'id' ) );
      _selectedObject[ 'cate_id' ] = $( ele ).attr( 'id' );
      _selectedObject[ 'cate_name' ] = $( ele ).text();
      tempArr.push( _selectedObject );
      _selectedObject = {};
    } )
  }
  vm.companyInfo.o_category = tempArr;
  vm.companyInfo.o_category_id = _selectedItemId;
} );

//销售渠道弹窗内确定事件
$( "#wayPopover button" ).on( "tap", function () {
  mui( '.mui-popover' ).popover( 'hide' );
  var _selectedItemId = [],
    _selectedObject = {},
    tempArr = [];
  if( $( "#wayPopover .active-item" ).length > 0 ) {
    $( "#wayPopover .active-item" ).each( function ( index, ele ) {
      _selectedItemId.push( $( ele ).attr( 'id' ) );
      _selectedObject[ 'channel_id' ] = $( ele ).attr( 'id' );
      _selectedObject[ 'channel_name' ] = $( ele ).text();
      tempArr.push( _selectedObject );
      _selectedObject = {};
    } )
  }
  vm.companyInfo.channel = tempArr;
  vm.companyInfo.channel_id = _selectedItemId;
} );

//主营类目品类的弹窗内确定事件
$( "#goodsPopover button" ).on( "tap", function () {
  mui( '.mui-popover' ).popover( 'hide' );
  var _selectedItemId = [],
    _selectedObject = {},
    tempArr = [];
  if( $( "#goodsPopover .active-item" ).length > 0 ) {
    $( "#goodsPopover .active-item" ).each( function ( index, ele ) {
      _selectedItemId.push( $( ele ).attr( 'id' ) );
      _selectedObject[ 'style_id' ] = $( ele ).attr( 'id' );
      _selectedObject[ 'style_name' ] = $( ele ).text();
      tempArr.push( _selectedObject );
      _selectedObject = {};
    } )
  }
  vm.companyInfo.style = tempArr;
  vm.companyInfo.style_id = _selectedItemId;
} );